API Reference
=============

This section provides detailed API documentation for pandalchemy.

Core Classes
------------

.. automodule:: pandalchemy.pandalchemy_base
   :members:
   :undoc-members:
   :show-inheritance:

TableDataFrame
--------------

.. automodule:: pandalchemy.tracked_dataframe
   :members:
   :undoc-members:
   :show-inheritance:

Change Tracking
---------------

.. automodule:: pandalchemy.change_tracker
   :members:
   :undoc-members:
   :show-inheritance:

Execution Planning
-------------------

.. automodule:: pandalchemy.execution_plan
   :members:
   :undoc-members:
   :show-inheritance:

SQL Operations
--------------

.. automodule:: pandalchemy.sql_operations
   :members:
   :undoc-members:
   :show-inheritance:

Exceptions
----------

.. automodule:: pandalchemy.exceptions
   :members:
   :undoc-members:
   :show-inheritance:

Utilities
---------

.. automodule:: pandalchemy.utils
   :members:
   :undoc-members:
   :show-inheritance:

Primary Key Utilities
----------------------

.. automodule:: pandalchemy.pk_utils
   :members:
   :undoc-members:
   :show-inheritance:

